# dwm-pracs

1. Classification Algorithm(Naive Bayes)
    - [Bhushan Python](https://github.com/bhushan-borole/dwm-pracs/blob/master/naive_bayes/naive_bayes_pandas.py)
    - [Vinay Python](https://github.com/bhushan-borole/dwm-pracs/blob/master/naive_bayes/nb_csv_vinay.py)  
    - [Rishabh Python](https://github.com/bhushan-borole/dwm-pracs/blob/master/naive_bayes/nb_rishabh.py)  
  
2. Linear Regression
    - [Rishabh Python](https://github.com/bhushan-borole/dwm-pracs/tree/master/linear_regression/rishabh)
    - [Vinay Python](https://github.com/vinay-deshmukh/DWM_Codes/blob/master/dwm-linear-regression/lin_reg.py)  
    - [Bhushan Python](https://github.com/bhushan-borole/dwm-pracs/tree/master/linear_regression/bhushan)

3. Clustering Algorithm (K means)
    - [Bhushan Python](https://github.com/bhushan-borole/dwm-pracs/blob/master/clustering/kmeans_clustering.py)
    - [Vinay Python (1-d data)](https://github.com/vinay-deshmukh/DWM_Codes/blob/master/dwm-kmeans/kmeans_new.py)

4. Association Rule Mining (Apriori)
   - [Bhushan Python](https://github.com/bhushan-borole/dwm-pracs/tree/master/apriori)
   - [Vinay Python](https://github.com/vinay-deshmukh/DWM_Codes/blob/master/dwm-apriori-algorithm/apriori_new.py)

5. Page Rank
   - [Bhushan Python](https://github.com/bhushan-borole/dwm-pracs/tree/master/pagerank)
   - [Vinay Python](https://github.com/vinay-deshmukh/DWM_Codes/blob/master/dwm-page-rank/page_rank.py)
